@@ -1,6 +1,7 @@
 # Generates distance to nearest neighbor
 
 #' @include Shazam.R
+#' @include Core.R
 NULL
 
 #### Classes ####
@@ -580,6 +581,9 @@ nearestDist <- function(sequences, model=c("ham", "aa", "hh_s1f", "hh_s5f", "mk_
             this_group <- crossGroups[i]
             other_groups <-  which(crossGroups != this_group)
             other_seq <- unique(sequences[other_groups])
+            if (model=="aa") {
+                seq_uniq <- names(seq_uniq)
+            }
             other_idx <- match(other_seq, seq_uniq)
             this_idx <- match(sequences[i], seq_uniq)
             
@@ -691,7 +695,9 @@ nearestDist <- function(sequences, model=c("ham", "aa", "hh_s1f", "hh_s5f", "mk_
 #'                           bulk sequencing data is assumed.
 #' @param    locusColumn     name of the column containing locus information. 
 #'                           Only applicable to single-cell data.
-#'                           Ignored if \code{cellIdColumn=NULL}.
+#'                           Ignored if \code{cellIdColumn=NULL}. Valid loci values
+#'                           are "IGH", "IGI", "IGK", "IGL", "TRA", "TRB", 
+#'                           "TRD", and "TRG".
 #' @param    onlyHeavy       use only the IGH (BCR) or TRB/TRD (TCR) sequences 
 #'                           for grouping. Only applicable to single-cell data.
 #'                           Ignored if \code{cellIdColumn=NULL}. 
@@ -1007,9 +1013,9 @@ distToNearest <- function(db, sequenceColumn="junction", vCallColumn="v_call", j
         idx <- uniqueGroupsIdx[[i]]
         
         if (singleCell) {
-            # only use IGH
+            # only use IGH, TRB, TRD
             # wrt idx
-            idxBool <- db[[locusColumn]][idx] == "IGH"
+            idxBool <- db[[locusColumn]][idx] %in% c("IGH", "TRB", "TRD")
         } else {
             idxBool <- rep(TRUE, length(idx))
         }
@@ -1018,9 +1024,8 @@ distToNearest <- function(db, sequenceColumn="junction", vCallColumn="v_call", j
         
         crossGroups <- NULL
         if (!is.null(cross)) {
-            crossGroups <- db_group %>% 
-              dplyr::group_by(!!!rlang::syms(cross)) %>%
-              dplyr::group_indices()
+              x <- dplyr::group_by(db_group, !!!rlang::syms(cross))
+              crossGroups <- dplyr::group_indices(x)
         }
         
         arrSeqs <-  db[[sequenceColumn]][idx]
@@ -1261,7 +1266,7 @@ findThreshold <- function (distances, method=c("density", "gmm"),
     # gaussian_scaling <- (1/(4 * pi))^(1/10)
     
     # Ideal bandwidth
-    bandwidth <- kedd::h.ucv(unique(distances), 4)$h
+    bandwidth <- h.ucv(unique(distances), 4)$h
     #bandwidth <- kedd::h.ucv(distances, 4)$h
     #bandwidth <- ks::hucv(unique(distances), deriv.order=4)
     
